TokenManager class

Manages auth tokens via ApStorage + fast in-memory cache. Zero external dependencies.

Constructors

TokenManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clearTokens() Future<void>
getRefreshToken() Future<String?>
getToken() Future<String?>
setRefreshToken(String token) Future<void>
setToken(String token) Future<void>
updateInMemory(String token) → void