CacheService class

Two-layer cache: fast in-memory Map + persistent SharedPreferences.

Constructors

CacheService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

buildKey(String url, Map<String, dynamic>? params) String
clearAll() Future<void>
get(String key) Future
invalidate(String key) Future<void>
set(String key, dynamic data, Duration duration) Future<void>