MultipartFileModel class
Represents a file to upload in a multipart request.
Constructors
-
MultipartFileModel({required String key, required String path, String? fileName, String? mimeType, List<
int> ? bytes}) -
const
-
MultipartFileModel.fromBytes({required String key, required List<
int> bytes, required String fileName, String? mimeType}) -
Create from in-memory bytes (no file path needed)
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited