ApStorage class

Pure Dart key-value storage using a local JSON file. Replaces shared_preferences — zero dependency.

Constructors

ApStorage()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clear() Future<void>
get<T>(String key) → T?
init() Future<void>
keys({String? prefix}) List<String>
remove(String key) Future<void>
set(String key, dynamic value) Future<void>