AutoPilotLogger class
AutoPilot Zero — Beautiful colored debug logger. Auto-disabled in release builds.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
cache(
String a, String k) → void -
configure(
{required bool enabled, required bool printPayload, required bool prettyPrint}) → void -
info(
String m) → void -
logError(
{required String url, required String error, int? statusCode, dynamic body, String? requestId}) → void -
logRequest(
{required String method, required String url, Map< String, String> ? headers, dynamic body, String? requestId}) → void -
logResponse(
{required String url, required int statusCode, required Duration responseTime, dynamic body, String? requestId}) → void -
queue(
String m) → void -
retry(
int n, int mx, String u) → void -
token(
String m) → void -
warn(
String m) → void