AutoPilotLogger class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
configure({required bool enabled, required bool printPayload, required bool prettyPrint})
→ void
-
-
logCache(String action, String key)
→ void
-
-
logError({required String url, required String error, int? statusCode, dynamic body, String? requestId})
→ void
-
-
logInfo(String msg)
→ void
-
-
logRequest({required String method, required String url, dynamic body, String? requestId})
→ void
-
-
logResponse({required String url, required int statusCode, required Duration responseTime, dynamic body, String? requestId})
→ void
-
-
logRetry(int attempt, int max, String url)
→ void
-
-
logToken(String action)
→ void
-
-
logWarn(String msg)
→ void
-