ResponseParser class

Parses raw HTTP response body into typed ApiResponse

Constructors

ResponseParser()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse<T>({required dynamic body, required int statusCode, required AutoPilotConfig cfg, T parser(dynamic json)?, required Duration responseTime, String? requestId}) ApiResponse<T>